django\_notifications.migrations.0001\_initial module
=====================================================

.. automodule:: django_notifications.migrations.0001_initial
   :members:
   :undoc-members:
   :show-inheritance:
